#! /usr/bin/env python
from    netCDF4               import    Dataset		
import  numpy                 as        np
import  matplotlib.pyplot     as        mpl
from matplotlib import colors,cm
import  math
from matplotlib import colors, ticker, cm
from scipy import interpolate

nc1a = Dataset('data_Early_Earth_hot_steamy_500Wm2_year4.nc') # THIS IS WHERE THE NETCDF OUTPUT FILE MUST BE SPECIFIED

Time1=nc1a.variables['Time'][:] 

lat= nc1a.variables['latitude'][:] #north latitude
lon= nc1a.variables['longitude'][:] #east longitude
AREA=nc1a.variables['aire'][:][:]
alt=nc1a.variables['altitude'][:]

latitude=np.zeros((len(lat),len(lon)),dtype='f')
longitude=np.zeros((len(lat),len(lon)),dtype='f')

# PREPARE 2D LAT/LON COORDINATES
for j in range(0,len(lon),1) :
   for i in range(0,len(lat),1) :
      latitude[i,j]=lat[i]
      longitude[i,j]=lon[j]

# GET VARIABLE (H2O_ICE_COL = INTEGRATED WATER ICE+LIQUID CLOUD COLUMN)
VAR1a=nc1a.variables['h2o_ice_col'][:][:][:]
# Incoming Solar Radiation
ISR1=nc1a.variables['ISR'][:][:][:]

x_2=np.zeros((len(lat),len(lon)),dtype='f')
y_2=np.zeros((len(lat),len(lon)),dtype='f')
z_2=np.zeros((len(lat),len(lon)),dtype='f')

x_3=np.zeros((len(lat),len(lon)),dtype='f')
y_3=np.zeros((len(lat),len(lon)),dtype='f')
z_3=np.zeros((len(lat),len(lon)),dtype='f')

new_lat=np.zeros((len(lat),len(lon)),dtype='f')
new_lon=np.zeros((len(lat),len(lon)),dtype='f')
ISR_local=np.zeros((len(lat),len(lon)),dtype='f')
ISR_new=np.zeros((len(lat),len(lon)),dtype='f')

OUT_VAR=np.zeros((len(Time1),len(lat),len(lon)),dtype='f')
OUT_VAR_CUMUL=np.zeros((len(lat),len(lon)),dtype='f')

for i in range(0,len(Time1),1): # TEMPORAL LOOP
 print (i, len(Time1))
 ISR1_index=np.where(ISR1[i,:,:] == np.amax(ISR1[i,:,:])) # GET THE SUBSOLAR POINT LONGITUDE/LATITUDE COORDINATES
 lat_rotate=-lat[ISR1_index[0][0]] # latitude  : + (90-lat)
 lon_rotate=-lon[ISR1_index[1][0]] # longitude : - (lon)
 f = interpolate.interp2d(lon,lat,VAR1a[i,:,:],kind='cubic')
 # 2D LOOP TO PERFORM THE ROTATION OF THE LAT/LON GRID TO CENTER THE SUBSOLAR POINT AT LONGITUDE 0 and LATITUDE 0
 for j in range(0,len(lat),1) :
  for k in range(0,len(lon),1) :
    x_2[j,k]=np.cos(lon[k]*np.pi/180.)*np.cos(lat[j]*np.pi/180.)
    y_2[j,k]=np.sin(lon[k]*np.pi/180.)*np.cos(lat[j]*np.pi/180.)
    z_2[j,k]=np.sin(lat[j]*np.pi/180.)
    x_3[j,k]=np.cos(lat_rotate*np.pi/180.)*np.cos(lon_rotate*np.pi/180.)*x_2[j,k]+np.sin(lon_rotate*np.pi/180.)*y_2[j,k]+np.sin(lat_rotate*np.pi/180.)*np.cos(lon_rotate*np.pi/180.)*z_2[j,k]
    y_3[j,k]=-np.cos(lat_rotate*np.pi/180.)*np.sin(lon_rotate*np.pi/180.)*x_2[j,k]+np.cos(lon_rotate*np.pi/180.)*y_2[j,k]-np.sin(lat_rotate*np.pi/180.)*np.sin(lon_rotate*np.pi/180.)*z_2[j,k]
    z_3[j,k]=-np.sin(lat_rotate*np.pi/180.)*x_2[j,k]+np.cos(lat_rotate*np.pi/180.)*z_2[j,k]
    new_lat[j,k]=np.arcsin(z_3[j,k])*180./np.pi
    new_lon[j,k]=np.arctan2(y_3[j,k],x_3[j,k])*180./np.pi
    # INTERPOLATE THE VARIABLE IN THE NEW LAT/LON GRID
    OUT_VAR[i,j,k]=f(new_lon[j,k],new_lat[j,k])
    # CALCULATE THE TEMPORAL MEAN
    OUT_VAR_CUMUL[j,k]=OUT_VAR_CUMUL[j,k]+OUT_VAR[i,j,k]/(len(Time1))
    
# THESE ARE THE LEVELS USED FOR THE CONTOUR PLOT

#levels1=np.arange(0.05,0.505,0.02)
#levels1=np.arange(0.,0.355,0.02)
#levels1=np.arange(0.05,0.352,0.02)
levels1=np.arange(0.,0.355,0.01)

FIG1=mpl.figure(1,figsize=(8,5))#,dpi=300)
ax1 = FIG1.add_subplot(1,1,1)
fig1=ax1.contourf(lon,lat,OUT_VAR_CUMUL[:,:],levels=levels1)
mpl.ylabel('Latitude')#,fontsize=7)
mpl.xlabel('Longitude')
ax1.tick_params(axis='y')#, labelsize=5)
ax1.tick_params(axis='x')#, labelsize=5)
cbarcol1=mpl.colorbar(fig1,orientation="vertical")
cbarcol1.ax.set_ylabel('water cloud column (kg/m2)')
mpl.show()
